[wgsl-reader] Add support for constant_id decoration

Bug: tint:155
Change-Id: I207fd87d0708c66ea0fe7de81b156db98eea8e60
Reviewed-on: https://dawn-review.googlesource.com/c/tint/+/39560
Commit-Queue: dan sinclair <dsinclair@chromium.org>
Auto-Submit: James Price <jrprice@google.com>
Reviewed-by: dan sinclair <dsinclair@chromium.org>
diff --git a/src/reader/wgsl/parser_impl.h b/src/reader/wgsl/parser_impl.h
index 56229b7..4105416 100644
--- a/src/reader/wgsl/parser_impl.h
+++ b/src/reader/wgsl/parser_impl.h
@@ -365,9 +365,11 @@
   /// @returns the variable parsed or nullptr
   /// @param decos the list of decorations for the variable declaration.
   Maybe<ast::Variable*> global_variable_decl(ast::DecorationList& decos);
   /// Parses a `global_constant_decl` grammar element
   /// @returns the const object or nullptr
-  Maybe<ast::Variable*> global_constant_decl();
+  /// @param decos the list of decorations for the constant declaration.
+  Maybe<ast::Variable*> global_constant_decl(ast::DecorationList& decos);
   /// Parses a `variable_decl` grammar element
   /// @returns the parsed variable declaration info
   Maybe<VarDeclInfo> variable_decl();
@@ -365,9 +365,11 @@
   /// @param decos the list of decorations for the variable declaration.
   Maybe<ast::Variable*> global_variable_decl(ast::DecorationList& decos);
-  /// Parses a `global_constant_decl` grammar element
+  /// Parses a `global_constant_decl` grammar element with the initial
+  /// `variable_decoration_list*` provided as `decos`
   /// @returns the const object or nullptr